"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import discussions_pb2
import events_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import groups_pb2
import pages_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _NodeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NodeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NODE_TYPE_UNSPECIFIED: _NodeType.ValueType  # 0
    NODE_TYPE_WORLD: _NodeType.ValueType  # 1
    NODE_TYPE_MACROREGION: _NodeType.ValueType  # 2
    NODE_TYPE_REGION: _NodeType.ValueType  # 3
    NODE_TYPE_SUBREGION: _NodeType.ValueType  # 4
    NODE_TYPE_LOCALITY: _NodeType.ValueType  # 5
    NODE_TYPE_SUBLOCALITY: _NodeType.ValueType  # 6

class NodeType(_NodeType, metaclass=_NodeTypeEnumTypeWrapper): ...

NODE_TYPE_UNSPECIFIED: NodeType.ValueType  # 0
NODE_TYPE_WORLD: NodeType.ValueType  # 1
NODE_TYPE_MACROREGION: NodeType.ValueType  # 2
NODE_TYPE_REGION: NodeType.ValueType  # 3
NODE_TYPE_SUBREGION: NodeType.ValueType  # 4
NODE_TYPE_LOCALITY: NodeType.ValueType  # 5
NODE_TYPE_SUBLOCALITY: NodeType.ValueType  # 6
Global___NodeType: typing_extensions.TypeAlias = NodeType

@typing.final
class Community(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    PARENTS_FIELD_NUMBER: builtins.int
    MAIN_PAGE_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ADMIN_FIELD_NUMBER: builtins.int
    MEMBER_COUNT_FIELD_NUMBER: builtins.int
    ADMIN_COUNT_FIELD_NUMBER: builtins.int
    NEARBY_USER_COUNT_FIELD_NUMBER: builtins.int
    CAN_MODERATE_FIELD_NUMBER: builtins.int
    SMALL_COMMUNITY_FEATURES_ENABLED_FIELD_NUMBER: builtins.int
    NODE_TYPE_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    name: builtins.str
    slug: builtins.str
    """a short URL fragment generated from the name, e.g. New York City: a guide to Phở might become
    new-york-city-guide-to-pho
    """
    description: builtins.str
    """CommonMark without images"""
    member: builtins.bool
    """whether the requesting user is member/admin"""
    admin: builtins.bool
    member_count: builtins.int
    admin_count: builtins.int
    nearby_user_count: builtins.int
    can_moderate: builtins.bool
    small_community_features_enabled: builtins.bool
    """Toggles the "small community" feature set: discussions, events, and public trips. These are
    grouped into a single flag because they're disabled together on large communities.
    """
    node_type: Global___NodeType.ValueType
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def parents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[groups_pb2.Parent]:
        """list of parents, ordered according to inclusion, e.g. World, US, New York, (NYC)"""

    @property
    def main_page(self) -> pages_pb2.Page:
        """we do not return the geometry here? (it's a potentially very big multipolygon)"""

    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        slug: builtins.str | None = ...,
        description: builtins.str | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        parents: collections.abc.Iterable[groups_pb2.Parent] | None = ...,
        main_page: pages_pb2.Page | None = ...,
        member: builtins.bool | None = ...,
        admin: builtins.bool | None = ...,
        member_count: builtins.int | None = ...,
        admin_count: builtins.int | None = ...,
        nearby_user_count: builtins.int | None = ...,
        can_moderate: builtins.bool | None = ...,
        small_community_features_enabled: builtins.bool | None = ...,
        node_type: Global___NodeType.ValueType | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["created", b"created", "main_page", b"main_page"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["admin", b"admin", "admin_count", b"admin_count", "can_moderate", b"can_moderate", "community_id", b"community_id", "created", b"created", "description", b"description", "main_page", b"main_page", "member", b"member", "member_count", b"member_count", "name", b"name", "nearby_user_count", b"nearby_user_count", "node_type", b"node_type", "parents", b"parents", "slug", b"slug", "small_community_features_enabled", b"small_community_features_enabled"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Community: typing_extensions.TypeAlias = Community

@typing.final
class GetCommunityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetCommunityReq: typing_extensions.TypeAlias = GetCommunityReq

@typing.final
class ListCommunitiesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    """leave blank (aka 0) to list all communities"""
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListCommunitiesReq: typing_extensions.TypeAlias = ListCommunitiesReq

@typing.final
class ListCommunitiesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def communities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Community]: ...
    def __init__(
        self,
        *,
        communities: collections.abc.Iterable[Global___Community] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["communities", b"communities", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListCommunitiesRes: typing_extensions.TypeAlias = ListCommunitiesRes

@typing.final
class ListUserCommunitiesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """the user to get communities from, set to 0 for current user"""
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size", "page_token", b"page_token", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListUserCommunitiesReq: typing_extensions.TypeAlias = ListUserCommunitiesReq

@typing.final
class ListUserCommunitiesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def communities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Community]: ...
    def __init__(
        self,
        *,
        communities: collections.abc.Iterable[Global___Community] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["communities", b"communities", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListUserCommunitiesRes: typing_extensions.TypeAlias = ListUserCommunitiesRes

@typing.final
class ListGroupsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListGroupsReq: typing_extensions.TypeAlias = ListGroupsReq

@typing.final
class ListGroupsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[groups_pb2.Group]: ...
    def __init__(
        self,
        *,
        groups: collections.abc.Iterable[groups_pb2.Group] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["groups", b"groups", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListGroupsRes: typing_extensions.TypeAlias = ListGroupsRes

@typing.final
class ListAdminsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListAdminsReq: typing_extensions.TypeAlias = ListAdminsReq

@typing.final
class ListAdminsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_USER_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def admin_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        admin_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["admin_user_ids", b"admin_user_ids", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListAdminsRes: typing_extensions.TypeAlias = ListAdminsRes

@typing.final
class AddAdminReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    community_id: builtins.int
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        community_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AddAdminReq: typing_extensions.TypeAlias = AddAdminReq

@typing.final
class RemoveAdminReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    community_id: builtins.int
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        community_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RemoveAdminReq: typing_extensions.TypeAlias = RemoveAdminReq

@typing.final
class ListMembersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListMembersReq: typing_extensions.TypeAlias = ListMembersReq

@typing.final
class ListMembersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBER_USER_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def member_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        member_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["member_user_ids", b"member_user_ids", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListMembersRes: typing_extensions.TypeAlias = ListMembersRes

@typing.final
class ListNearbyUsersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListNearbyUsersReq: typing_extensions.TypeAlias = ListNearbyUsersReq

@typing.final
class ListNearbyUsersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEARBY_USER_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def nearby_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        nearby_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["nearby_user_ids", b"nearby_user_ids", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListNearbyUsersRes: typing_extensions.TypeAlias = ListNearbyUsersRes

@typing.final
class ListPlacesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPlacesReq: typing_extensions.TypeAlias = ListPlacesReq

@typing.final
class ListPlacesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def places(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[pages_pb2.Page]: ...
    def __init__(
        self,
        *,
        places: collections.abc.Iterable[pages_pb2.Page] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "places", b"places"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPlacesRes: typing_extensions.TypeAlias = ListPlacesRes

@typing.final
class ListGuidesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListGuidesReq: typing_extensions.TypeAlias = ListGuidesReq

@typing.final
class ListGuidesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GUIDES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def guides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[pages_pb2.Page]: ...
    def __init__(
        self,
        *,
        guides: collections.abc.Iterable[pages_pb2.Page] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["guides", b"guides", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListGuidesRes: typing_extensions.TypeAlias = ListGuidesRes

@typing.final
class ListEventsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAST_FIELD_NUMBER: builtins.int
    INCLUDE_PARENTS_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    past: builtins.bool
    include_parents: builtins.bool
    """whether to include events in all parent communities as well"""
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        past: builtins.bool | None = ...,
        include_parents: builtins.bool | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "include_parents", b"include_parents", "page_size", b"page_size", "page_token", b"page_token", "past", b"past"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventsReq: typing_extensions.TypeAlias = ListEventsReq

@typing.final
class ListEventsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[events_pb2.Event]: ...
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[events_pb2.Event] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["events", b"events", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventsRes: typing_extensions.TypeAlias = ListEventsRes

@typing.final
class ListDiscussionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListDiscussionsReq: typing_extensions.TypeAlias = ListDiscussionsReq

@typing.final
class ListDiscussionsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISCUSSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def discussions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[discussions_pb2.Discussion]: ...
    def __init__(
        self,
        *,
        discussions: collections.abc.Iterable[discussions_pb2.Discussion] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["discussions", b"discussions", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListDiscussionsRes: typing_extensions.TypeAlias = ListDiscussionsRes

@typing.final
class JoinCommunityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___JoinCommunityReq: typing_extensions.TypeAlias = JoinCommunityReq

@typing.final
class LeaveCommunityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___LeaveCommunityReq: typing_extensions.TypeAlias = LeaveCommunityReq

@typing.final
class SearchCommunitiesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    query: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        query: builtins.str | None = ...,
        page_size: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size", "query", b"query"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SearchCommunitiesReq: typing_extensions.TypeAlias = SearchCommunitiesReq

@typing.final
class SearchCommunitiesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITIES_FIELD_NUMBER: builtins.int
    @property
    def communities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Community]: ...
    def __init__(
        self,
        *,
        communities: collections.abc.Iterable[Global___Community] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["communities", b"communities"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SearchCommunitiesRes: typing_extensions.TypeAlias = SearchCommunitiesRes

@typing.final
class CommunitySummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    MEMBER_COUNT_FIELD_NUMBER: builtins.int
    PARENTS_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    NODE_TYPE_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    name: builtins.str
    slug: builtins.str
    member: builtins.bool
    member_count: builtins.int
    node_type: Global___NodeType.ValueType
    @property
    def parents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[groups_pb2.Parent]:
        """list of parents, ordered according to inclusion, for hierarchical ordering"""

    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        slug: builtins.str | None = ...,
        member: builtins.bool | None = ...,
        member_count: builtins.int | None = ...,
        parents: collections.abc.Iterable[groups_pb2.Parent] | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        node_type: Global___NodeType.ValueType | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["created", b"created"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "created", b"created", "member", b"member", "member_count", b"member_count", "name", b"name", "node_type", b"node_type", "parents", b"parents", "slug", b"slug"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CommunitySummary: typing_extensions.TypeAlias = CommunitySummary

@typing.final
class ListAllCommunitiesReq(google.protobuf.message.Message):
    """empty for now, but allows for future filtering/pagination parameters"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ListAllCommunitiesReq: typing_extensions.TypeAlias = ListAllCommunitiesReq

@typing.final
class ListAllCommunitiesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITIES_FIELD_NUMBER: builtins.int
    @property
    def communities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___CommunitySummary]: ...
    def __init__(
        self,
        *,
        communities: collections.abc.Iterable[Global___CommunitySummary] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["communities", b"communities"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListAllCommunitiesRes: typing_extensions.TypeAlias = ListAllCommunitiesRes

@typing.final
class ListRecentCommunitiesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """number of communities to return; server caps this to a sensible maximum"""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListRecentCommunitiesReq: typing_extensions.TypeAlias = ListRecentCommunitiesReq

@typing.final
class ListRecentCommunitiesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITIES_FIELD_NUMBER: builtins.int
    @property
    def communities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___CommunitySummary]: ...
    def __init__(
        self,
        *,
        communities: collections.abc.Iterable[Global___CommunitySummary] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["communities", b"communities"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListRecentCommunitiesRes: typing_extensions.TypeAlias = ListRecentCommunitiesRes



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import galleries_pb2 as galleries__pb2


class GalleriesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetGallery = channel.unary_unary(
                '/org.couchers.api.galleries.Galleries/GetGallery',
                request_serializer=galleries__pb2.GetGalleryReq.SerializeToString,
                response_deserializer=galleries__pb2.PhotoGallery.FromString,
                )
        self.AddPhotoToGallery = channel.unary_unary(
                '/org.couchers.api.galleries.Galleries/AddPhotoToGallery',
                request_serializer=galleries__pb2.AddPhotoToGalleryReq.SerializeToString,
                response_deserializer=galleries__pb2.PhotoGallery.FromString,
                )
        self.RemovePhotoFromGallery = channel.unary_unary(
                '/org.couchers.api.galleries.Galleries/RemovePhotoFromGallery',
                request_serializer=galleries__pb2.RemovePhotoFromGalleryReq.SerializeToString,
                response_deserializer=galleries__pb2.PhotoGallery.FromString,
                )
        self.MovePhoto = channel.unary_unary(
                '/org.couchers.api.galleries.Galleries/MovePhoto',
                request_serializer=galleries__pb2.MovePhotoReq.SerializeToString,
                response_deserializer=galleries__pb2.PhotoGallery.FromString,
                )
        self.UpdatePhotoCaption = channel.unary_unary(
                '/org.couchers.api.galleries.Galleries/UpdatePhotoCaption',
                request_serializer=galleries__pb2.UpdatePhotoCaptionReq.SerializeToString,
                response_deserializer=galleries__pb2.PhotoGallery.FromString,
                )
        self.GetGalleryEditInfo = channel.unary_unary(
                '/org.couchers.api.galleries.Galleries/GetGalleryEditInfo',
                request_serializer=galleries__pb2.GetGalleryEditInfoReq.SerializeToString,
                response_deserializer=galleries__pb2.GetGalleryEditInfoRes.FromString,
                )


class GalleriesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetGallery(self, request, context):
        """Get a specific gallery by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPhotoToGallery(self, request, context):
        """Add a photo to your gallery (appended to end)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePhotoFromGallery(self, request, context):
        """Remove a photo from your gallery
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MovePhoto(self, request, context):
        """Move a photo to a new position in the gallery
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePhotoCaption(self, request, context):
        """Update the caption of a specific photo
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGalleryEditInfo(self, request, context):
        """Get edit info for a gallery you own (e.g., max_photos)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GalleriesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetGallery': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGallery,
                    request_deserializer=galleries__pb2.GetGalleryReq.FromString,
                    response_serializer=galleries__pb2.PhotoGallery.SerializeToString,
            ),
            'AddPhotoToGallery': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPhotoToGallery,
                    request_deserializer=galleries__pb2.AddPhotoToGalleryReq.FromString,
                    response_serializer=galleries__pb2.PhotoGallery.SerializeToString,
            ),
            'RemovePhotoFromGallery': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePhotoFromGallery,
                    request_deserializer=galleries__pb2.RemovePhotoFromGalleryReq.FromString,
                    response_serializer=galleries__pb2.PhotoGallery.SerializeToString,
            ),
            'MovePhoto': grpc.unary_unary_rpc_method_handler(
                    servicer.MovePhoto,
                    request_deserializer=galleries__pb2.MovePhotoReq.FromString,
                    response_serializer=galleries__pb2.PhotoGallery.SerializeToString,
            ),
            'UpdatePhotoCaption': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePhotoCaption,
                    request_deserializer=galleries__pb2.UpdatePhotoCaptionReq.FromString,
                    response_serializer=galleries__pb2.PhotoGallery.SerializeToString,
            ),
            'GetGalleryEditInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGalleryEditInfo,
                    request_deserializer=galleries__pb2.GetGalleryEditInfoReq.FromString,
                    response_serializer=galleries__pb2.GetGalleryEditInfoRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.galleries.Galleries', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Galleries(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetGallery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.galleries.Galleries/GetGallery',
            galleries__pb2.GetGalleryReq.SerializeToString,
            galleries__pb2.PhotoGallery.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddPhotoToGallery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.galleries.Galleries/AddPhotoToGallery',
            galleries__pb2.AddPhotoToGalleryReq.SerializeToString,
            galleries__pb2.PhotoGallery.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemovePhotoFromGallery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.galleries.Galleries/RemovePhotoFromGallery',
            galleries__pb2.RemovePhotoFromGalleryReq.SerializeToString,
            galleries__pb2.PhotoGallery.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MovePhoto(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.galleries.Galleries/MovePhoto',
            galleries__pb2.MovePhotoReq.SerializeToString,
            galleries__pb2.PhotoGallery.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePhotoCaption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.galleries.Galleries/UpdatePhotoCaption',
            galleries__pb2.UpdatePhotoCaptionReq.SerializeToString,
            galleries__pb2.PhotoGallery.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGalleryEditInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.galleries.Galleries/GetGalleryEditInfo',
            galleries__pb2.GetGalleryEditInfoReq.SerializeToString,
            galleries__pb2.GetGalleryEditInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import api_pb2
import builtins
import collections.abc
import communities_pb2
import events_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import groups_pb2
import pages_pb2
import requests_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Area(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    RADIUS_FIELD_NUMBER: builtins.int
    lat: builtins.float
    lng: builtins.float
    radius: builtins.float
    """m"""
    def __init__(
        self,
        *,
        lat: builtins.float | None = ...,
        lng: builtins.float | None = ...,
        radius: builtins.float | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["lat", b"lat", "lng", b"lng", "radius", b"radius"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Area: typing_extensions.TypeAlias = Area

@typing.final
class RectArea(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAT_MIN_FIELD_NUMBER: builtins.int
    LAT_MAX_FIELD_NUMBER: builtins.int
    LNG_MIN_FIELD_NUMBER: builtins.int
    LNG_MAX_FIELD_NUMBER: builtins.int
    lat_min: builtins.float
    lat_max: builtins.float
    lng_min: builtins.float
    lng_max: builtins.float
    def __init__(
        self,
        *,
        lat_min: builtins.float | None = ...,
        lat_max: builtins.float | None = ...,
        lng_min: builtins.float | None = ...,
        lng_max: builtins.float | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["lat_max", b"lat_max", "lat_min", b"lat_min", "lng_max", b"lng_max", "lng_min", b"lng_min"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RectArea: typing_extensions.TypeAlias = RectArea

@typing.final
class SearchReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    INCLUDE_USERS_FIELD_NUMBER: builtins.int
    INCLUDE_COMMUNITIES_FIELD_NUMBER: builtins.int
    INCLUDE_GROUPS_FIELD_NUMBER: builtins.int
    INCLUDE_PLACES_FIELD_NUMBER: builtins.int
    INCLUDE_GUIDES_FIELD_NUMBER: builtins.int
    INCLUDE_EVENTS_FIELD_NUMBER: builtins.int
    TITLE_ONLY_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    query: builtins.str
    """there are two modes: full text search and fuzzy title search (trigram), see `//docs/search.md` for overview
    in normal mode we use full text to search through all content (including titles) plus fuzzy search through titles
    only, in rankings fuzzy has a bit higher weight because of the inner workings
    when you set title_only, we don't do full text search, only fuzzy title search
    in full text search, you can use the following operators:
    * `"quote text"`` to search for a chunk of consequtive text
    * `or` to search for one or another search term
    * `-` (minus) to ignore a search term
    in the fuzzy search these have no meaning
    """
    include_users: builtins.bool
    include_communities: builtins.bool
    include_groups: builtins.bool
    include_places: builtins.bool
    include_guides: builtins.bool
    include_events: builtins.bool
    """bool include_discussions = 9;"""
    title_only: builtins.bool
    """restrictions on area
    oneof search_in {
      // search in given area
      Area search_in_area = 11;
      // search inside the area defined by the community
      int64 search_in_community_id = 12;
    }

    whether to only perform a trigram based search on titles and not do full text search
    """
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        query: builtins.str | None = ...,
        include_users: builtins.bool | None = ...,
        include_communities: builtins.bool | None = ...,
        include_groups: builtins.bool | None = ...,
        include_places: builtins.bool | None = ...,
        include_guides: builtins.bool | None = ...,
        include_events: builtins.bool | None = ...,
        title_only: builtins.bool | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["include_communities", b"include_communities", "include_events", b"include_events", "include_groups", b"include_groups", "include_guides", b"include_guides", "include_places", b"include_places", "include_users", b"include_users", "page_size", b"page_size", "page_token", b"page_token", "query", b"query", "title_only", b"title_only"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SearchReq: typing_extensions.TypeAlias = SearchReq

@typing.final
class Result(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RANK_FIELD_NUMBER: builtins.int
    SNIPPET_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    COMMUNITY_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    PLACE_FIELD_NUMBER: builtins.int
    GUIDE_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    rank: builtins.float
    """a ranking score, higher is more relevant"""
    snippet: builtins.str
    """a snippet of the matched parts of the document"""
    @property
    def user(self) -> api_pb2.User: ...
    @property
    def community(self) -> communities_pb2.Community: ...
    @property
    def group(self) -> groups_pb2.Group: ...
    @property
    def place(self) -> pages_pb2.Page: ...
    @property
    def guide(self) -> pages_pb2.Page: ...
    @property
    def event(self) -> events_pb2.Event:
        """org.couchers.api.discussions.Discussion discussion = 9;"""

    def __init__(
        self,
        *,
        rank: builtins.float | None = ...,
        snippet: builtins.str | None = ...,
        user: api_pb2.User | None = ...,
        community: communities_pb2.Community | None = ...,
        group: groups_pb2.Group | None = ...,
        place: pages_pb2.Page | None = ...,
        guide: pages_pb2.Page | None = ...,
        event: events_pb2.Event | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["community", b"community", "event", b"event", "group", b"group", "guide", b"guide", "place", b"place", "result", b"result", "user", b"user"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community", b"community", "event", b"event", "group", b"group", "guide", b"guide", "place", b"place", "rank", b"rank", "result", b"result", "snippet", b"snippet", "user", b"user"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_result: typing_extensions.TypeAlias = typing.Literal["user", "community", "group", "place", "guide", "event"]
    _WhichOneofArgType_result: typing_extensions.TypeAlias = typing.Literal["result", b"result"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_result) -> _WhichOneofReturnType_result | None: ...

Global___Result: typing_extensions.TypeAlias = Result

@typing.final
class SearchRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Result]:
        """sorted with highest rank first"""

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[Global___Result] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "results", b"results"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SearchRes: typing_extensions.TypeAlias = SearchRes

@typing.final
class UserSearchReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXACTLY_USER_IDS_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    QUERY_NAME_ONLY_FIELD_NUMBER: builtins.int
    LAST_ACTIVE_FIELD_NUMBER: builtins.int
    SEARCH_IN_AREA_FIELD_NUMBER: builtins.int
    SEARCH_IN_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    SEARCH_IN_RECTANGLE_FIELD_NUMBER: builtins.int
    HOSTING_STATUS_FILTER_FIELD_NUMBER: builtins.int
    SMOKING_LOCATION_FILTER_FIELD_NUMBER: builtins.int
    SLEEPING_ARRANGEMENT_FILTER_FIELD_NUMBER: builtins.int
    PARKING_DETAILS_FILTER_FIELD_NUMBER: builtins.int
    MEETUP_STATUS_FILTER_FIELD_NUMBER: builtins.int
    LANGUAGE_ABILITY_FILTER_FIELD_NUMBER: builtins.int
    GUESTS_FIELD_NUMBER: builtins.int
    ONLY_WITH_REFERENCES_FIELD_NUMBER: builtins.int
    ONLY_WITH_STRONG_VERIFICATION_FIELD_NUMBER: builtins.int
    AGE_MIN_FIELD_NUMBER: builtins.int
    AGE_MAX_FIELD_NUMBER: builtins.int
    LAST_MINUTE_FIELD_NUMBER: builtins.int
    HAS_PETS_FIELD_NUMBER: builtins.int
    ACCEPTS_PETS_FIELD_NUMBER: builtins.int
    HAS_KIDS_FIELD_NUMBER: builtins.int
    ACCEPTS_KIDS_FIELD_NUMBER: builtins.int
    HAS_HOUSEMATES_FIELD_NUMBER: builtins.int
    WHEELCHAIR_ACCESSIBLE_FIELD_NUMBER: builtins.int
    SMOKES_AT_HOME_FIELD_NUMBER: builtins.int
    DRINKING_ALLOWED_FIELD_NUMBER: builtins.int
    DRINKS_AT_HOME_FIELD_NUMBER: builtins.int
    PARKING_FIELD_NUMBER: builtins.int
    CAMPING_OK_FIELD_NUMBER: builtins.int
    PROFILE_COMPLETED_FIELD_NUMBER: builtins.int
    SAME_GENDER_ONLY_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    query_name_only: builtins.bool
    """whether the query (if any) should only search through username and display name"""
    search_in_community_id: builtins.int
    """search inside the area defined by the community"""
    only_with_references: builtins.bool
    only_with_strong_verification: builtins.bool
    same_gender_only: builtins.bool
    page_size: builtins.int
    page_token: builtins.str
    @property
    def exactly_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """if this field is present, we filter to exactly these users (any invalid ids are ignored)"""

    @property
    def query(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def last_active(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """coarsened"""

    @property
    def search_in_area(self) -> Global___Area:
        """search in given area"""

    @property
    def search_in_rectangle(self) -> Global___RectArea: ...
    @property
    def hosting_status_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[api_pb2.HostingStatus.ValueType]: ...
    @property
    def smoking_location_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[api_pb2.SmokingLocation.ValueType]: ...
    @property
    def sleeping_arrangement_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[api_pb2.SleepingArrangement.ValueType]: ...
    @property
    def parking_details_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[api_pb2.ParkingDetails.ValueType]: ...
    @property
    def meetup_status_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[api_pb2.MeetupStatus.ValueType]: ...
    @property
    def language_ability_filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[api_pb2.LanguageAbility]: ...
    @property
    def guests(self) -> google.protobuf.wrappers_pb2.UInt32Value: ...
    @property
    def age_min(self) -> google.protobuf.wrappers_pb2.UInt32Value:
        """bool friends_only = 13;"""

    @property
    def age_max(self) -> google.protobuf.wrappers_pb2.UInt32Value: ...
    @property
    def last_minute(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def has_pets(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def accepts_pets(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def has_kids(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def accepts_kids(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def has_housemates(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def wheelchair_accessible(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def smokes_at_home(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def drinking_allowed(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def drinks_at_home(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def parking(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def camping_ok(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def profile_completed(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        exactly_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        query: google.protobuf.wrappers_pb2.StringValue | None = ...,
        query_name_only: builtins.bool | None = ...,
        last_active: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        search_in_area: Global___Area | None = ...,
        search_in_community_id: builtins.int | None = ...,
        search_in_rectangle: Global___RectArea | None = ...,
        hosting_status_filter: collections.abc.Iterable[api_pb2.HostingStatus.ValueType] | None = ...,
        smoking_location_filter: collections.abc.Iterable[api_pb2.SmokingLocation.ValueType] | None = ...,
        sleeping_arrangement_filter: collections.abc.Iterable[api_pb2.SleepingArrangement.ValueType] | None = ...,
        parking_details_filter: collections.abc.Iterable[api_pb2.ParkingDetails.ValueType] | None = ...,
        meetup_status_filter: collections.abc.Iterable[api_pb2.MeetupStatus.ValueType] | None = ...,
        language_ability_filter: collections.abc.Iterable[api_pb2.LanguageAbility] | None = ...,
        guests: google.protobuf.wrappers_pb2.UInt32Value | None = ...,
        only_with_references: builtins.bool | None = ...,
        only_with_strong_verification: builtins.bool | None = ...,
        age_min: google.protobuf.wrappers_pb2.UInt32Value | None = ...,
        age_max: google.protobuf.wrappers_pb2.UInt32Value | None = ...,
        last_minute: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        has_pets: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        accepts_pets: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        has_kids: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        accepts_kids: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        has_housemates: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        wheelchair_accessible: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        smokes_at_home: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        drinking_allowed: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        drinks_at_home: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        parking: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        camping_ok: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        profile_completed: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        same_gender_only: builtins.bool | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["accepts_kids", b"accepts_kids", "accepts_pets", b"accepts_pets", "age_max", b"age_max", "age_min", b"age_min", "camping_ok", b"camping_ok", "drinking_allowed", b"drinking_allowed", "drinks_at_home", b"drinks_at_home", "guests", b"guests", "has_housemates", b"has_housemates", "has_kids", b"has_kids", "has_pets", b"has_pets", "last_active", b"last_active", "last_minute", b"last_minute", "parking", b"parking", "profile_completed", b"profile_completed", "query", b"query", "search_in", b"search_in", "search_in_area", b"search_in_area", "search_in_community_id", b"search_in_community_id", "search_in_rectangle", b"search_in_rectangle", "smokes_at_home", b"smokes_at_home", "wheelchair_accessible", b"wheelchair_accessible"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["accepts_kids", b"accepts_kids", "accepts_pets", b"accepts_pets", "age_max", b"age_max", "age_min", b"age_min", "camping_ok", b"camping_ok", "drinking_allowed", b"drinking_allowed", "drinks_at_home", b"drinks_at_home", "exactly_user_ids", b"exactly_user_ids", "guests", b"guests", "has_housemates", b"has_housemates", "has_kids", b"has_kids", "has_pets", b"has_pets", "hosting_status_filter", b"hosting_status_filter", "language_ability_filter", b"language_ability_filter", "last_active", b"last_active", "last_minute", b"last_minute", "meetup_status_filter", b"meetup_status_filter", "only_with_references", b"only_with_references", "only_with_strong_verification", b"only_with_strong_verification", "page_size", b"page_size", "page_token", b"page_token", "parking", b"parking", "parking_details_filter", b"parking_details_filter", "profile_completed", b"profile_completed", "query", b"query", "query_name_only", b"query_name_only", "same_gender_only", b"same_gender_only", "search_in", b"search_in", "search_in_area", b"search_in_area", "search_in_community_id", b"search_in_community_id", "search_in_rectangle", b"search_in_rectangle", "sleeping_arrangement_filter", b"sleeping_arrangement_filter", "smokes_at_home", b"smokes_at_home", "smoking_location_filter", b"smoking_location_filter", "wheelchair_accessible", b"wheelchair_accessible"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_search_in: typing_extensions.TypeAlias = typing.Literal["search_in_area", "search_in_community_id", "search_in_rectangle"]
    _WhichOneofArgType_search_in: typing_extensions.TypeAlias = typing.Literal["search_in", b"search_in"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_search_in) -> _WhichOneofReturnType_search_in | None: ...

Global___UserSearchReq: typing_extensions.TypeAlias = UserSearchReq

@typing.final
class UserSearchRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_ITEMS_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    total_items: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Result]:
        """sorted with highest rank first
        this will only contain users
        """

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[Global___Result] | None = ...,
        next_page_token: builtins.str | None = ...,
        total_items: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "results", b"results", "total_items", b"total_items"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UserSearchRes: typing_extensions.TypeAlias = UserSearchRes

@typing.final
class SearchUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    JOINED_FIELD_NUMBER: builtins.int
    HAS_COMPLETED_PROFILE_FIELD_NUMBER: builtins.int
    HAS_COMPLETED_MY_HOME_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    PROFILE_SNIPPET_FIELD_NUMBER: builtins.int
    NUM_REFERENCES_FIELD_NUMBER: builtins.int
    GENDER_FIELD_NUMBER: builtins.int
    AGE_FIELD_NUMBER: builtins.int
    LAST_ACTIVE_FIELD_NUMBER: builtins.int
    HOSTING_STATUS_FIELD_NUMBER: builtins.int
    MEETUP_STATUS_FIELD_NUMBER: builtins.int
    AVATAR_URL_FIELD_NUMBER: builtins.int
    AVATAR_THUMBNAIL_URL_FIELD_NUMBER: builtins.int
    HAS_STRONG_VERIFICATION_FIELD_NUMBER: builtins.int
    INSUFFICIENT_DATA_FIELD_NUMBER: builtins.int
    LOW_FIELD_NUMBER: builtins.int
    SOME_FIELD_NUMBER: builtins.int
    MOST_FIELD_NUMBER: builtins.int
    ALMOST_ALL_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    username: builtins.str
    name: builtins.str
    city: builtins.str
    has_completed_profile: builtins.bool
    has_completed_my_home: builtins.bool
    lat: builtins.float
    lng: builtins.float
    profile_snippet: builtins.str
    """plain text"""
    num_references: builtins.int
    gender: builtins.str
    age: builtins.int
    hosting_status: api_pb2.HostingStatus.ValueType
    meetup_status: api_pb2.MeetupStatus.ValueType
    avatar_url: builtins.str
    avatar_thumbnail_url: builtins.str
    has_strong_verification: builtins.bool
    @property
    def joined(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """not exact"""

    @property
    def last_active(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """not exact"""

    @property
    def insufficient_data(self) -> requests_pb2.ResponseRateInsufficientData:
        """received <3 requests"""

    @property
    def low(self) -> requests_pb2.ResponseRateLow:
        """response rate <= 33%"""

    @property
    def some(self) -> requests_pb2.ResponseRateSome:
        """response rate > 33%, but <= 66%"""

    @property
    def most(self) -> requests_pb2.ResponseRateMost:
        """response rate > 66%, but <= 90%"""

    @property
    def almost_all(self) -> requests_pb2.ResponseRateAlmostAll:
        """response rate > 90%"""

    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        username: builtins.str | None = ...,
        name: builtins.str | None = ...,
        city: builtins.str | None = ...,
        joined: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        has_completed_profile: builtins.bool | None = ...,
        has_completed_my_home: builtins.bool | None = ...,
        lat: builtins.float | None = ...,
        lng: builtins.float | None = ...,
        profile_snippet: builtins.str | None = ...,
        num_references: builtins.int | None = ...,
        gender: builtins.str | None = ...,
        age: builtins.int | None = ...,
        last_active: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        hosting_status: api_pb2.HostingStatus.ValueType | None = ...,
        meetup_status: api_pb2.MeetupStatus.ValueType | None = ...,
        avatar_url: builtins.str | None = ...,
        avatar_thumbnail_url: builtins.str | None = ...,
        has_strong_verification: builtins.bool | None = ...,
        insufficient_data: requests_pb2.ResponseRateInsufficientData | None = ...,
        low: requests_pb2.ResponseRateLow | None = ...,
        some: requests_pb2.ResponseRateSome | None = ...,
        most: requests_pb2.ResponseRateMost | None = ...,
        almost_all: requests_pb2.ResponseRateAlmostAll | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["almost_all", b"almost_all", "insufficient_data", b"insufficient_data", "joined", b"joined", "last_active", b"last_active", "low", b"low", "most", b"most", "response_rate", b"response_rate", "some", b"some"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["age", b"age", "almost_all", b"almost_all", "avatar_thumbnail_url", b"avatar_thumbnail_url", "avatar_url", b"avatar_url", "city", b"city", "gender", b"gender", "has_completed_my_home", b"has_completed_my_home", "has_completed_profile", b"has_completed_profile", "has_strong_verification", b"has_strong_verification", "hosting_status", b"hosting_status", "insufficient_data", b"insufficient_data", "joined", b"joined", "last_active", b"last_active", "lat", b"lat", "lng", b"lng", "low", b"low", "meetup_status", b"meetup_status", "most", b"most", "name", b"name", "num_references", b"num_references", "profile_snippet", b"profile_snippet", "response_rate", b"response_rate", "some", b"some", "user_id", b"user_id", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_response_rate: typing_extensions.TypeAlias = typing.Literal["insufficient_data", "low", "some", "most", "almost_all"]
    _WhichOneofArgType_response_rate: typing_extensions.TypeAlias = typing.Literal["response_rate", b"response_rate"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_response_rate) -> _WhichOneofReturnType_response_rate | None: ...

Global___SearchUser: typing_extensions.TypeAlias = SearchUser

@typing.final
class UserSearchV2Res(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_ITEMS_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    total_items: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___SearchUser]: ...
    def __init__(
        self,
        *,
        results: collections.abc.Iterable[Global___SearchUser] | None = ...,
        next_page_token: builtins.str | None = ...,
        total_items: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "results", b"results", "total_items", b"total_items"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UserSearchV2Res: typing_extensions.TypeAlias = UserSearchV2Res

@typing.final
class EventSearchReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAST_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    QUERY_TITLE_ONLY_FIELD_NUMBER: builtins.int
    SUBSCRIBED_FIELD_NUMBER: builtins.int
    ATTENDING_FIELD_NUMBER: builtins.int
    ORGANIZING_FIELD_NUMBER: builtins.int
    MY_COMMUNITIES_FIELD_NUMBER: builtins.int
    INCLUDE_CANCELLED_FIELD_NUMBER: builtins.int
    SEARCH_IN_AREA_FIELD_NUMBER: builtins.int
    SEARCH_IN_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    SEARCH_IN_RECTANGLE_FIELD_NUMBER: builtins.int
    AFTER_FIELD_NUMBER: builtins.int
    BEFORE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    EXCLUDE_ATTENDING_FIELD_NUMBER: builtins.int
    past: builtins.bool
    """whether to paginate backwards"""
    query_title_only: builtins.bool
    """whether the query (if any) should only search through event title and not event description"""
    subscribed: builtins.bool
    """all false => everything"""
    attending: builtins.bool
    organizing: builtins.bool
    my_communities: builtins.bool
    """include events in the user's communities"""
    include_cancelled: builtins.bool
    search_in_community_id: builtins.int
    """search inside the area defined by the community"""
    page_size: builtins.int
    page_token: builtins.str
    page_number: builtins.int
    exclude_attending: builtins.bool
    """exclude events the user is already attending or organizing (useful with my_communities)"""
    @property
    def query(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def search_in_area(self) -> Global___Area:
        """search in given area"""

    @property
    def search_in_rectangle(self) -> Global___RectArea: ...
    @property
    def after(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """restrictions in time"""

    @property
    def before(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        past: builtins.bool | None = ...,
        query: google.protobuf.wrappers_pb2.StringValue | None = ...,
        query_title_only: builtins.bool | None = ...,
        subscribed: builtins.bool | None = ...,
        attending: builtins.bool | None = ...,
        organizing: builtins.bool | None = ...,
        my_communities: builtins.bool | None = ...,
        include_cancelled: builtins.bool | None = ...,
        search_in_area: Global___Area | None = ...,
        search_in_community_id: builtins.int | None = ...,
        search_in_rectangle: Global___RectArea | None = ...,
        after: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        before: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        page_number: builtins.int | None = ...,
        exclude_attending: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["after", b"after", "before", b"before", "page_number", b"page_number", "page_token", b"page_token", "pagination", b"pagination", "query", b"query", "search_in", b"search_in", "search_in_area", b"search_in_area", "search_in_community_id", b"search_in_community_id", "search_in_rectangle", b"search_in_rectangle"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["after", b"after", "attending", b"attending", "before", b"before", "exclude_attending", b"exclude_attending", "include_cancelled", b"include_cancelled", "my_communities", b"my_communities", "organizing", b"organizing", "page_number", b"page_number", "page_size", b"page_size", "page_token", b"page_token", "pagination", b"pagination", "past", b"past", "query", b"query", "query_title_only", b"query_title_only", "search_in", b"search_in", "search_in_area", b"search_in_area", "search_in_community_id", b"search_in_community_id", "search_in_rectangle", b"search_in_rectangle", "subscribed", b"subscribed"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_pagination: typing_extensions.TypeAlias = typing.Literal["page_token", "page_number"]
    _WhichOneofArgType_pagination: typing_extensions.TypeAlias = typing.Literal["pagination", b"pagination"]
    _WhichOneofReturnType_search_in: typing_extensions.TypeAlias = typing.Literal["search_in_area", "search_in_community_id", "search_in_rectangle"]
    _WhichOneofArgType_search_in: typing_extensions.TypeAlias = typing.Literal["search_in", b"search_in"]
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType_pagination) -> _WhichOneofReturnType_pagination | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType_search_in) -> _WhichOneofReturnType_search_in | None: ...

Global___EventSearchReq: typing_extensions.TypeAlias = EventSearchReq

@typing.final
class EventSearchRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_ITEMS_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    total_items: builtins.int
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[events_pb2.Event]: ...
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[events_pb2.Event] | None = ...,
        next_page_token: builtins.str | None = ...,
        total_items: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["events", b"events", "next_page_token", b"next_page_token", "total_items", b"total_items"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EventSearchRes: typing_extensions.TypeAlias = EventSearchRes



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import bugs_pb2
import collections.abc
import google.api.httpbody_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class BugsStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Version: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, bugs_pb2.VersionInfo]
    ReportBug: grpc.UnaryUnaryMultiCallable[bugs_pb2.ReportBugReq, bugs_pb2.ReportBugRes]
    """Report a bug"""
    Status: grpc.UnaryUnaryMultiCallable[bugs_pb2.StatusReq, bugs_pb2.StatusRes]
    GetDescriptors: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, google.api.httpbody_pb2.HttpBody]
    GetNativeUpdateManifest: grpc.UnaryUnaryMultiCallable[google.api.httpbody_pb2.HttpBody, google.api.httpbody_pb2.HttpBody]
    GeolocationSearchInfo: grpc.UnaryUnaryMultiCallable[bugs_pb2.GeolocationSearchInfoReq, google.protobuf.empty_pb2.Empty]
    GeolocationClickInfo: grpc.UnaryUnaryMultiCallable[bugs_pb2.GeolocationClickInfoReq, google.protobuf.empty_pb2.Empty]
    ReportDiagnostics: grpc.UnaryUnaryMultiCallable[bugs_pb2.ReportDiagnosticsReq, google.protobuf.empty_pb2.Empty]
    CheckNativeStatus: grpc.UnaryUnaryMultiCallable[bugs_pb2.CheckNativeStatusReq, bugs_pb2.CheckNativeStatusRes]
    """Diagnostics ping from the native mobile apps."""
    EvaluateFeatureFlag: grpc.UnaryUnaryMultiCallable[bugs_pb2.EvaluateFeatureFlagReq, bugs_pb2.EvaluateFeatureFlagRes]
    """Remotely evaluate a single feature flag for the current session's user (anonymously when
    logged out) and return the resolved value. Evaluated one flag at a time, on demand, so the
    server only evaluates flags the client actually uses - which keeps exposure logging accurate.
    """
    LogExperimentExposure: grpc.UnaryUnaryMultiCallable[bugs_pb2.LogExperimentExposureReq, google.protobuf.empty_pb2.Empty]
    """Record a client-side experiment exposure, reported by the SDK as the user is bucketed."""

class BugsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Version(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> bugs_pb2.VersionInfo: ...

    @abc.abstractmethod
    def ReportBug(
        self,
        request: bugs_pb2.ReportBugReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> bugs_pb2.ReportBugRes:
        """Report a bug"""

    @abc.abstractmethod
    def Status(
        self,
        request: bugs_pb2.StatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> bugs_pb2.StatusRes: ...

    @abc.abstractmethod
    def GetDescriptors(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.api.httpbody_pb2.HttpBody: ...

    @abc.abstractmethod
    def GetNativeUpdateManifest(
        self,
        request: google.api.httpbody_pb2.HttpBody,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.api.httpbody_pb2.HttpBody: ...

    @abc.abstractmethod
    def GeolocationSearchInfo(
        self,
        request: bugs_pb2.GeolocationSearchInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def GeolocationClickInfo(
        self,
        request: bugs_pb2.GeolocationClickInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def ReportDiagnostics(
        self,
        request: bugs_pb2.ReportDiagnosticsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def CheckNativeStatus(
        self,
        request: bugs_pb2.CheckNativeStatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> bugs_pb2.CheckNativeStatusRes:
        """Diagnostics ping from the native mobile apps."""

    @abc.abstractmethod
    def EvaluateFeatureFlag(
        self,
        request: bugs_pb2.EvaluateFeatureFlagReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> bugs_pb2.EvaluateFeatureFlagRes:
        """Remotely evaluate a single feature flag for the current session's user (anonymously when
        logged out) and return the resolved value. Evaluated one flag at a time, on demand, so the
        server only evaluates flags the client actually uses - which keeps exposure logging accurate.
        """

    @abc.abstractmethod
    def LogExperimentExposure(
        self,
        request: bugs_pb2.LogExperimentExposureReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Record a client-side experiment exposure, reported by the SDK as the user is bucketed."""

def add_BugsServicer_to_server(servicer: BugsServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dashboard.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2
from . import account_pb2 as account__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import requests_pb2 as requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64\x61shboard.proto\x12\x1aorg.couchers.api.dashboard\x1a\x11\x61nnotations.proto\x1a\raccount.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0erequests.proto\"\x13\n\x11GetDashboardV2Req\"\xa8\x03\n\x11GetDashboardV2Res\x12<\n\treminders\x18\x01 \x01(\x0b\x32).org.couchers.api.account.GetRemindersRes\x12?\n\x07surfing\x18\x02 \x01(\x0b\x32..org.couchers.api.requests.ListHostRequestsRes\x12?\n\x07hosting\x18\x03 \x01(\x0b\x32..org.couchers.api.requests.ListHostRequestsRes\x12;\n\tmy_events\x18\x04 \x01(\x0b\x32(.org.couchers.api.events.ListMyEventsRes\x12\x42\n\x10\x63ommunity_events\x18\x05 \x01(\x0b\x32(.org.couchers.api.events.ListMyEventsRes\x12R\n\x0b\x64iscussions\x18\x06 \x01(\x0b\x32=.org.couchers.api.discussions.ListMyCommunitiesDiscussionsRes2\x83\x01\n\tDashboard\x12p\n\x0eGetDashboardV2\x12-.org.couchers.api.dashboard.GetDashboardV2Req\x1a-.org.couchers.api.dashboard.GetDashboardV2Res\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dashboard_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DASHBOARD']._loaded_options = None
  _globals['_DASHBOARD']._serialized_options = b'\210\265\030\003'
  _globals['_GETDASHBOARDV2REQ']._serialized_start=130
  _globals['_GETDASHBOARDV2REQ']._serialized_end=149
  _globals['_GETDASHBOARDV2RES']._serialized_start=152
  _globals['_GETDASHBOARDV2RES']._serialized_end=576
  _globals['_DASHBOARD']._serialized_start=579
  _globals['_DASHBOARD']._serialized_end=710
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import api_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ContributeOption:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ContributeOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ContributeOption.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONTRIBUTE_OPTION_UNSPECIFIED: _ContributeOption.ValueType  # 0
    CONTRIBUTE_OPTION_YES: _ContributeOption.ValueType  # 1
    CONTRIBUTE_OPTION_MAYBE: _ContributeOption.ValueType  # 2
    CONTRIBUTE_OPTION_NO: _ContributeOption.ValueType  # 3

class ContributeOption(_ContributeOption, metaclass=_ContributeOptionEnumTypeWrapper): ...

CONTRIBUTE_OPTION_UNSPECIFIED: ContributeOption.ValueType  # 0
CONTRIBUTE_OPTION_YES: ContributeOption.ValueType  # 1
CONTRIBUTE_OPTION_MAYBE: ContributeOption.ValueType  # 2
CONTRIBUTE_OPTION_NO: ContributeOption.ValueType  # 3
Global___ContributeOption: typing_extensions.TypeAlias = ContributeOption

@typing.final
class SignupFlowReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLOW_TOKEN_FIELD_NUMBER: builtins.int
    BASIC_FIELD_NUMBER: builtins.int
    ACCOUNT_FIELD_NUMBER: builtins.int
    FEEDBACK_FIELD_NUMBER: builtins.int
    MOTIVATIONS_FIELD_NUMBER: builtins.int
    EMAIL_TOKEN_FIELD_NUMBER: builtins.int
    ACCEPT_COMMUNITY_GUIDELINES_FIELD_NUMBER: builtins.int
    RESEND_VERIFICATION_EMAIL_FIELD_NUMBER: builtins.int
    flow_token: builtins.str
    """a token used to link the user's information across the signup flow
    required if basic is empty, otherwise the backend generates a new signup
    """
    email_token: builtins.str
    """email token is reused for both verifying a signup's email, but also for continuing a signup"""
    resend_verification_email: builtins.bool
    @property
    def basic(self) -> Global___SignupBasic: ...
    @property
    def account(self) -> Global___SignupAccount: ...
    @property
    def feedback(self) -> Global___ContributorForm: ...
    @property
    def motivations(self) -> Global___SignupMotivations: ...
    @property
    def accept_community_guidelines(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        flow_token: builtins.str | None = ...,
        basic: Global___SignupBasic | None = ...,
        account: Global___SignupAccount | None = ...,
        feedback: Global___ContributorForm | None = ...,
        motivations: Global___SignupMotivations | None = ...,
        email_token: builtins.str | None = ...,
        accept_community_guidelines: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        resend_verification_email: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["accept_community_guidelines", b"accept_community_guidelines", "account", b"account", "basic", b"basic", "feedback", b"feedback", "motivations", b"motivations"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["accept_community_guidelines", b"accept_community_guidelines", "account", b"account", "basic", b"basic", "email_token", b"email_token", "feedback", b"feedback", "flow_token", b"flow_token", "motivations", b"motivations", "resend_verification_email", b"resend_verification_email"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SignupFlowReq: typing_extensions.TypeAlias = SignupFlowReq

@typing.final
class SignupFlowRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLOW_TOKEN_FIELD_NUMBER: builtins.int
    AUTH_RES_FIELD_NUMBER: builtins.int
    NEED_BASIC_FIELD_NUMBER: builtins.int
    NEED_ACCOUNT_FIELD_NUMBER: builtins.int
    NEED_FEEDBACK_FIELD_NUMBER: builtins.int
    NEED_MOTIVATIONS_FIELD_NUMBER: builtins.int
    NEED_VERIFY_EMAIL_FIELD_NUMBER: builtins.int
    NEED_ACCEPT_COMMUNITY_GUIDELINES_FIELD_NUMBER: builtins.int
    flow_token: builtins.str
    """a token used to link the user's information across the signup flow"""
    need_basic: builtins.bool
    """which parts are missing?"""
    need_account: builtins.bool
    need_feedback: builtins.bool
    need_motivations: builtins.bool
    need_verify_email: builtins.bool
    """user needs to verify their email"""
    need_accept_community_guidelines: builtins.bool
    @property
    def auth_res(self) -> Global___AuthRes:
        """auth_res is included if and only if signup is successful"""

    def __init__(
        self,
        *,
        flow_token: builtins.str | None = ...,
        auth_res: Global___AuthRes | None = ...,
        need_basic: builtins.bool | None = ...,
        need_account: builtins.bool | None = ...,
        need_feedback: builtins.bool | None = ...,
        need_motivations: builtins.bool | None = ...,
        need_verify_email: builtins.bool | None = ...,
        need_accept_community_guidelines: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["auth_res", b"auth_res"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["auth_res", b"auth_res", "flow_token", b"flow_token", "need_accept_community_guidelines", b"need_accept_community_guidelines", "need_account", b"need_account", "need_basic", b"need_basic", "need_feedback", b"need_feedback", "need_motivations", b"need_motivations", "need_verify_email", b"need_verify_email"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SignupFlowRes: typing_extensions.TypeAlias = SignupFlowRes

@typing.final
class SignupBasic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    INVITE_CODE_FIELD_NUMBER: builtins.int
    name: builtins.str
    email: builtins.str
    invite_code: builtins.str
    """TODO: UTM parameters, attribution"""
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        email: builtins.str | None = ...,
        invite_code: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["email", b"email", "invite_code", b"invite_code", "name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SignupBasic: typing_extensions.TypeAlias = SignupBasic

@typing.final
class SignupTokenInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNUP_TOKEN_FIELD_NUMBER: builtins.int
    signup_token: builtins.str
    def __init__(
        self,
        *,
        signup_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["signup_token", b"signup_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SignupTokenInfoReq: typing_extensions.TypeAlias = SignupTokenInfoReq

@typing.final
class SignupAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    RADIUS_FIELD_NUMBER: builtins.int
    BIRTHDATE_FIELD_NUMBER: builtins.int
    GENDER_FIELD_NUMBER: builtins.int
    HOSTING_STATUS_FIELD_NUMBER: builtins.int
    ACCEPT_TOS_FIELD_NUMBER: builtins.int
    OPT_OUT_OF_NEWSLETTER_FIELD_NUMBER: builtins.int
    username: builtins.str
    """Should be lowercase ascii, matching regex [a-z][0-9a-z_]*[a-z0-9]"""
    password: builtins.str
    city: builtins.str
    lat: builtins.float
    lng: builtins.float
    radius: builtins.float
    """meters"""
    birthdate: builtins.str
    """in YYYY-MM-DD format"""
    gender: builtins.str
    hosting_status: api_pb2.HostingStatus.ValueType
    accept_tos: builtins.bool
    opt_out_of_newsletter: builtins.bool
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
        password: builtins.str | None = ...,
        city: builtins.str | None = ...,
        lat: builtins.float | None = ...,
        lng: builtins.float | None = ...,
        radius: builtins.float | None = ...,
        birthdate: builtins.str | None = ...,
        gender: builtins.str | None = ...,
        hosting_status: api_pb2.HostingStatus.ValueType | None = ...,
        accept_tos: builtins.bool | None = ...,
        opt_out_of_newsletter: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["accept_tos", b"accept_tos", "birthdate", b"birthdate", "city", b"city", "gender", b"gender", "hosting_status", b"hosting_status", "lat", b"lat", "lng", b"lng", "opt_out_of_newsletter", b"opt_out_of_newsletter", "password", b"password", "radius", b"radius", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SignupAccount: typing_extensions.TypeAlias = SignupAccount

@typing.final
class SignupMotivations(google.protobuf.message.Message):
    """Information about how the user heard about Couchers and what they want to do"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEARD_ABOUT_COUCHERS_FIELD_NUMBER: builtins.int
    MOTIVATIONS_FIELD_NUMBER: builtins.int
    heard_about_couchers: builtins.str
    """How they heard about Couchers (free text, e.g., "friend", "social_media", "former_cs_member", "other")"""
    @property
    def motivations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """What they're looking to do - can select multiple (e.g., "surfing", "hosting", "events", "community_organizing", "something_else")"""

    def __init__(
        self,
        *,
        heard_about_couchers: builtins.str | None = ...,
        motivations: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["heard_about_couchers", b"heard_about_couchers", "motivations", b"motivations"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SignupMotivations: typing_extensions.TypeAlias = SignupMotivations

@typing.final
class UsernameValidReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    username: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UsernameValidReq: typing_extensions.TypeAlias = UsernameValidReq

@typing.final
class UsernameValidRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALID_FIELD_NUMBER: builtins.int
    valid: builtins.bool
    def __init__(
        self,
        *,
        valid: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["valid", b"valid"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UsernameValidRes: typing_extensions.TypeAlias = UsernameValidRes

@typing.final
class AuthReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    REMEMBER_DEVICE_FIELD_NUMBER: builtins.int
    user: builtins.str
    password: builtins.str
    remember_device: builtins.bool
    """whether to remember the browser or not
    if false, the session will time out after 7 days of inactivity (no API calls)
    if true, the session is valid from creation until expiry, with no need to be used in between
    """
    def __init__(
        self,
        *,
        user: builtins.str | None = ...,
        password: builtins.str | None = ...,
        remember_device: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["password", b"password", "remember_device", b"remember_device", "user", b"user"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AuthReq: typing_extensions.TypeAlias = AuthReq

@typing.final
class AuthRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    JAILED_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """user_id of the user"""
    jailed: builtins.bool
    """whether the user has to complete some additional steps to continue to the
    platform
    """
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        jailed: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["jailed", b"jailed", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AuthRes: typing_extensions.TypeAlias = AuthRes

@typing.final
class GetAuthStateRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGGED_IN_FIELD_NUMBER: builtins.int
    AUTH_RES_FIELD_NUMBER: builtins.int
    logged_in: builtins.bool
    @property
    def auth_res(self) -> Global___AuthRes:
        """only filled out if logged_in is true"""

    def __init__(
        self,
        *,
        logged_in: builtins.bool | None = ...,
        auth_res: Global___AuthRes | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["auth_res", b"auth_res"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["auth_res", b"auth_res", "logged_in", b"logged_in"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetAuthStateRes: typing_extensions.TypeAlias = GetAuthStateRes

@typing.final
class ResetPasswordReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    user: builtins.str
    def __init__(
        self,
        *,
        user: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user", b"user"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ResetPasswordReq: typing_extensions.TypeAlias = ResetPasswordReq

@typing.final
class CompletePasswordResetV2Req(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_RESET_TOKEN_FIELD_NUMBER: builtins.int
    NEW_PASSWORD_FIELD_NUMBER: builtins.int
    password_reset_token: builtins.str
    new_password: builtins.str
    """the frontend should ask for the password twice and whatnot"""
    def __init__(
        self,
        *,
        password_reset_token: builtins.str | None = ...,
        new_password: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["new_password", b"new_password", "password_reset_token", b"password_reset_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CompletePasswordResetV2Req: typing_extensions.TypeAlias = CompletePasswordResetV2Req

@typing.final
class ConfirmChangeEmailV2Req(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANGE_EMAIL_TOKEN_FIELD_NUMBER: builtins.int
    change_email_token: builtins.str
    def __init__(
        self,
        *,
        change_email_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["change_email_token", b"change_email_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ConfirmChangeEmailV2Req: typing_extensions.TypeAlias = ConfirmChangeEmailV2Req

@typing.final
class ContributorForm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDEAS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    EXPERIENCE_FIELD_NUMBER: builtins.int
    CONTRIBUTE_FIELD_NUMBER: builtins.int
    CONTRIBUTE_WAYS_FIELD_NUMBER: builtins.int
    EXPERTISE_FIELD_NUMBER: builtins.int
    ideas: builtins.str
    """all fields are optional"""
    features: builtins.str
    experience: builtins.str
    contribute: Global___ContributeOption.ValueType
    """if contribute is set to yes or maybe, then contribute, contribute_ways and expertise are required."""
    expertise: builtins.str
    @property
    def contribute_ways(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        ideas: builtins.str | None = ...,
        features: builtins.str | None = ...,
        experience: builtins.str | None = ...,
        contribute: Global___ContributeOption.ValueType | None = ...,
        contribute_ways: collections.abc.Iterable[builtins.str] | None = ...,
        expertise: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["contribute", b"contribute", "contribute_ways", b"contribute_ways", "experience", b"experience", "expertise", b"expertise", "features", b"features", "ideas", b"ideas"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ContributorForm: typing_extensions.TypeAlias = ContributorForm

@typing.final
class ConfirmDeleteAccountReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    token: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["token", b"token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ConfirmDeleteAccountReq: typing_extensions.TypeAlias = ConfirmDeleteAccountReq

@typing.final
class RecoverAccountReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    token: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["token", b"token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RecoverAccountReq: typing_extensions.TypeAlias = RecoverAccountReq

@typing.final
class UnsubscribeReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAYLOAD_FIELD_NUMBER: builtins.int
    SIG_FIELD_NUMBER: builtins.int
    payload: builtins.bytes
    """frontend should decode the base64 in urls and send raw bytes"""
    sig: builtins.bytes
    def __init__(
        self,
        *,
        payload: builtins.bytes | None = ...,
        sig: builtins.bytes | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["payload", b"payload", "sig", b"sig"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UnsubscribeReq: typing_extensions.TypeAlias = UnsubscribeReq

@typing.final
class UnsubscribeRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    """returned only on success, otherwise errors out the RPC"""
    def __init__(
        self,
        *,
        response: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["response", b"response"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UnsubscribeRes: typing_extensions.TypeAlias = UnsubscribeRes

@typing.final
class AntiBotReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    token: builtins.str
    action: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str | None = ...,
        action: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["action", b"action", "token", b"token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AntiBotReq: typing_extensions.TypeAlias = AntiBotReq

@typing.final
class AntiBotRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___AntiBotRes: typing_extensions.TypeAlias = AntiBotRes

@typing.final
class AntiBotPolicyReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___AntiBotPolicyReq: typing_extensions.TypeAlias = AntiBotPolicyReq

@typing.final
class AntiBotPolicyRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOULD_ANTIBOT_FIELD_NUMBER: builtins.int
    should_antibot: builtins.bool
    def __init__(
        self,
        *,
        should_antibot: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["should_antibot", b"should_antibot"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AntiBotPolicyRes: typing_extensions.TypeAlias = AntiBotPolicyRes

@typing.final
class GetInviteCodeInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.str
    def __init__(
        self,
        *,
        code: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["code", b"code"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetInviteCodeInfoReq: typing_extensions.TypeAlias = GetInviteCodeInfoReq

@typing.final
class GetInviteCodeInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    AVATAR_URL_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    username: builtins.str
    avatar_url: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        username: builtins.str | None = ...,
        avatar_url: builtins.str | None = ...,
        url: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["avatar_url", b"avatar_url", "name", b"name", "url", b"url", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetInviteCodeInfoRes: typing_extensions.TypeAlias = GetInviteCodeInfoRes



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import threads_pb2
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PAGE_TYPE_PLACE: _PageType.ValueType  # 0
    """point of interest, landmark, tourist attraction, etc"""
    PAGE_TYPE_GUIDE: _PageType.ValueType  # 1
    """guide"""
    PAGE_TYPE_MAIN_PAGE: _PageType.ValueType  # 2
    """main page of a group or a community"""

class PageType(_PageType, metaclass=_PageTypeEnumTypeWrapper): ...

PAGE_TYPE_PLACE: PageType.ValueType  # 0
"""point of interest, landmark, tourist attraction, etc"""
PAGE_TYPE_GUIDE: PageType.ValueType  # 1
"""guide"""
PAGE_TYPE_MAIN_PAGE: PageType.ValueType  # 2
"""main page of a group or a community"""
Global___PageType: typing_extensions.TypeAlias = PageType

@typing.final
class Coordinate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    lat: builtins.float
    lng: builtins.float
    def __init__(
        self,
        *,
        lat: builtins.float | None = ...,
        lng: builtins.float | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["lat", b"lat", "lng", b"lng"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Coordinate: typing_extensions.TypeAlias = Coordinate

@typing.final
class Page(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    LAST_EDITED_FIELD_NUMBER: builtins.int
    LAST_EDITOR_USER_ID_FIELD_NUMBER: builtins.int
    CREATOR_USER_ID_FIELD_NUMBER: builtins.int
    OWNER_USER_ID_FIELD_NUMBER: builtins.int
    OWNER_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    OWNER_GROUP_ID_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PHOTO_URL_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    EDITOR_USER_IDS_FIELD_NUMBER: builtins.int
    CAN_EDIT_FIELD_NUMBER: builtins.int
    CAN_MODERATE_FIELD_NUMBER: builtins.int
    page_id: builtins.int
    type: Global___PageType.ValueType
    slug: builtins.str
    """a short URL fragment generated from the name, e.g. New York City: a guide to Phở might become
    new-york-city-guide-to-pho
    """
    last_editor_user_id: builtins.int
    creator_user_id: builtins.int
    owner_user_id: builtins.int
    owner_community_id: builtins.int
    owner_group_id: builtins.int
    title: builtins.str
    content: builtins.str
    """CommonMark without images"""
    photo_url: builtins.str
    """empty string if no photo"""
    address: builtins.str
    can_edit: builtins.bool
    can_moderate: builtins.bool
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_edited(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def thread(self) -> threads_pb2.Thread: ...
    @property
    def location(self) -> Global___Coordinate: ...
    @property
    def editor_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        page_id: builtins.int | None = ...,
        type: Global___PageType.ValueType | None = ...,
        slug: builtins.str | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_edited: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_editor_user_id: builtins.int | None = ...,
        creator_user_id: builtins.int | None = ...,
        owner_user_id: builtins.int | None = ...,
        owner_community_id: builtins.int | None = ...,
        owner_group_id: builtins.int | None = ...,
        thread: threads_pb2.Thread | None = ...,
        title: builtins.str | None = ...,
        content: builtins.str | None = ...,
        photo_url: builtins.str | None = ...,
        address: builtins.str | None = ...,
        location: Global___Coordinate | None = ...,
        editor_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        can_edit: builtins.bool | None = ...,
        can_moderate: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["created", b"created", "last_edited", b"last_edited", "location", b"location", "owner", b"owner", "owner_community_id", b"owner_community_id", "owner_group_id", b"owner_group_id", "owner_user_id", b"owner_user_id", "thread", b"thread"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "can_edit", b"can_edit", "can_moderate", b"can_moderate", "content", b"content", "created", b"created", "creator_user_id", b"creator_user_id", "editor_user_ids", b"editor_user_ids", "last_edited", b"last_edited", "last_editor_user_id", b"last_editor_user_id", "location", b"location", "owner", b"owner", "owner_community_id", b"owner_community_id", "owner_group_id", b"owner_group_id", "owner_user_id", b"owner_user_id", "page_id", b"page_id", "photo_url", b"photo_url", "slug", b"slug", "thread", b"thread", "title", b"title", "type", b"type"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_owner: typing_extensions.TypeAlias = typing.Literal["owner_user_id", "owner_community_id", "owner_group_id"]
    _WhichOneofArgType_owner: typing_extensions.TypeAlias = typing.Literal["owner", b"owner"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_owner) -> _WhichOneofReturnType_owner | None: ...

Global___Page: typing_extensions.TypeAlias = Page

@typing.final
class CreatePlaceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PHOTO_KEY_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    title: builtins.str
    content: builtins.str
    photo_key: builtins.str
    """from media server"""
    address: builtins.str
    @property
    def location(self) -> Global___Coordinate: ...
    def __init__(
        self,
        *,
        title: builtins.str | None = ...,
        content: builtins.str | None = ...,
        photo_key: builtins.str | None = ...,
        address: builtins.str | None = ...,
        location: Global___Coordinate | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["location", b"location"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "content", b"content", "location", b"location", "photo_key", b"photo_key", "title", b"title"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreatePlaceReq: typing_extensions.TypeAlias = CreatePlaceReq

@typing.final
class CreateGuideReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PHOTO_KEY_FIELD_NUMBER: builtins.int
    PARENT_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    title: builtins.str
    content: builtins.str
    photo_key: builtins.str
    """from media server"""
    parent_community_id: builtins.int
    address: builtins.str
    """optional"""
    @property
    def location(self) -> Global___Coordinate:
        """optional"""

    def __init__(
        self,
        *,
        title: builtins.str | None = ...,
        content: builtins.str | None = ...,
        photo_key: builtins.str | None = ...,
        parent_community_id: builtins.int | None = ...,
        address: builtins.str | None = ...,
        location: Global___Coordinate | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["location", b"location"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "content", b"content", "location", b"location", "parent_community_id", b"parent_community_id", "photo_key", b"photo_key", "title", b"title"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateGuideReq: typing_extensions.TypeAlias = CreateGuideReq

@typing.final
class GetPageReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_ID_FIELD_NUMBER: builtins.int
    page_id: builtins.int
    def __init__(
        self,
        *,
        page_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_id", b"page_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetPageReq: typing_extensions.TypeAlias = GetPageReq

@typing.final
class UpdatePageReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PHOTO_KEY_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    page_id: builtins.int
    @property
    def title(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def content(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def photo_key(self) -> google.protobuf.wrappers_pb2.StringValue:
        """from media server, set to empty string to clear"""

    @property
    def address(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def location(self) -> Global___Coordinate:
        """we can detect lack of this sub-message without *Value stuff, and location cannot be set to null"""

    def __init__(
        self,
        *,
        page_id: builtins.int | None = ...,
        title: google.protobuf.wrappers_pb2.StringValue | None = ...,
        content: google.protobuf.wrappers_pb2.StringValue | None = ...,
        photo_key: google.protobuf.wrappers_pb2.StringValue | None = ...,
        address: google.protobuf.wrappers_pb2.StringValue | None = ...,
        location: Global___Coordinate | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "content", b"content", "location", b"location", "photo_key", b"photo_key", "title", b"title"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "content", b"content", "location", b"location", "page_id", b"page_id", "photo_key", b"photo_key", "title", b"title"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdatePageReq: typing_extensions.TypeAlias = UpdatePageReq

@typing.final
class TransferPageReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_ID_FIELD_NUMBER: builtins.int
    NEW_OWNER_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    NEW_OWNER_GROUP_ID_FIELD_NUMBER: builtins.int
    page_id: builtins.int
    new_owner_community_id: builtins.int
    new_owner_group_id: builtins.int
    def __init__(
        self,
        *,
        page_id: builtins.int | None = ...,
        new_owner_community_id: builtins.int | None = ...,
        new_owner_group_id: builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["new_owner", b"new_owner", "new_owner_community_id", b"new_owner_community_id", "new_owner_group_id", b"new_owner_group_id"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["new_owner", b"new_owner", "new_owner_community_id", b"new_owner_community_id", "new_owner_group_id", b"new_owner_group_id", "page_id", b"page_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_new_owner: typing_extensions.TypeAlias = typing.Literal["new_owner_community_id", "new_owner_group_id"]
    _WhichOneofArgType_new_owner: typing_extensions.TypeAlias = typing.Literal["new_owner", b"new_owner"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_new_owner) -> _WhichOneofReturnType_new_owner | None: ...

Global___TransferPageReq: typing_extensions.TypeAlias = TransferPageReq

@typing.final
class ListUserPlacesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """the user to get places from, set to 0 for current user"""
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size", "page_token", b"page_token", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListUserPlacesReq: typing_extensions.TypeAlias = ListUserPlacesReq

@typing.final
class ListUserPlacesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def places(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Page]: ...
    def __init__(
        self,
        *,
        places: collections.abc.Iterable[Global___Page] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "places", b"places"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListUserPlacesRes: typing_extensions.TypeAlias = ListUserPlacesRes

@typing.final
class ListUserGuidesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """the user to get guides from, set to 0 for current user"""
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size", "page_token", b"page_token", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListUserGuidesReq: typing_extensions.TypeAlias = ListUserGuidesReq

@typing.final
class ListUserGuidesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GUIDES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def guides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Page]: ...
    def __init__(
        self,
        *,
        guides: collections.abc.Iterable[Global___Page] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["guides", b"guides", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListUserGuidesRes: typing_extensions.TypeAlias = ListUserGuidesRes
